==> apache-camel-2.20.3-src.zip: apache-camel-2.20.3/components/camel-spring/src/test/java/org/apache/camel/spring/processor/SpringXPathFilterWithNamespaceOnRouteContextTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;

import org.apache.camel.CamelContext;
import org.apache.camel.processor.XPathFilterTest;

import static org.apache.camel.spring.processor.SpringTestHelper.createSpringCamelContext;

/**
 *
 */
public class SpringXPathFilterWithNamespaceOnRouteContextTest extends XPathFilterTest {

    @Override
    protected void setUp() throws Exception {
        matchingBody = "<person name='James' city='London' xmlns='http://example.com/person'/>";
        super.setUp();
    }

    protected CamelContext createCamelContext() throws Exception {
        return createSpringCamelContext(this, "org/apache/camel/spring/processor/xpathFilterWithNamespaceOnRouteContext.xml");
    }
}

==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-spring/src/test/java/org/apache/camel/spring/processor/SpringXPathFilterWithNamespaceOnRouteContextTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;
import org.apache.camel.CamelContext;
import org.apache.camel.processor.XPathFilterTest;
import org.junit.Before;

import static org.apache.camel.spring.processor.SpringTestHelper.createSpringCamelContext;

/**
 *
 */
public class SpringXPathFilterWithNamespaceOnRouteContextTest extends XPathFilterTest {

    @Override
    @Before
    public void setUp() throws Exception {
        matchingBody = "<person name='James' city='London' xmlns='http://example.com/person'/>";
        super.setUp();
    }

    protected CamelContext createCamelContext() throws Exception {
        return createSpringCamelContext(this, "org/apache/camel/spring/processor/xpathFilterWithNamespaceOnRouteContext.xml");
    }
}
